==> odoo12_addon_barcodes_generator_product-12.0.1.0.0.99.dev8-py3-none-any.whl: odoo/addons/barcodes_generator_product/models/product_template.py <==
# Copyright (C) 2014-Today GRAP (http://www.grap.coop)
# Copyright (C) 2016-Today La Louve (http://www.lalouve.net)
# @author: Sylvain LE GAL (https://twitter.com/legalsylvain)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models

from odoo.addons.barcodes_generator_abstract.models.barcode_rule\
    import _GENERATE_TYPE


class ProductTemplate(models.Model):
    _inherit = 'product.template'

    # Related to display product product information if is_product_variant
    barcode_rule_id = fields.Many2one(
        related='product_variant_ids.barcode_rule_id',
        string='Barcode Rule', readonly=False, comodel_name='barcode.rule')

    barcode_base = fields.Integer(
        related='product_variant_ids.barcode_base',
        readonly=False, string='Barcode Base')

    generate_type = fields.Selection(
        string='Generate Type', selection=_GENERATE_TYPE, readonly=True,
        related='product_variant_ids.barcode_rule_id.generate_type')

    # View Section
    @api.multi
    def generate_base(self):
        self.product_variant_ids.generate_base()

    @api.multi
    def generate_barcode(self):
        self.ensure_one()
        self.product_variant_ids.generate_barcode()

    @api.onchange('barcode_rule_id')
    def onchange_barcode_rule_id(self):
        self.generate_type = self.barcode_rule_id.generate_type

    # Overload Section
    @api.model
    def create(self, vals):
        template = super(ProductTemplate, self).create(vals)

        # this is needed to set given values to first variant after creation
        # these fields should be moved to product as lead to confusion
        # (Ref. product module feature in Odoo Core)
        related_vals = {}
        for field in ['barcode_rule_id', 'barcode_base']:
            if vals.get(field, False):
                related_vals[field] = vals[field]
            if related_vals:
                template.write(related_vals)
        return template

==> odoo12_addon_barcodes_generator_product-12.0.1.0.2-py3-none-any.whl: odoo/addons/barcodes_generator_product/models/product_template.py <==
# Copyright (C) 2014-Today GRAP (http://www.grap.coop)
# Copyright (C) 2016-Today La Louve (http://www.lalouve.net)
# @author: Sylvain LE GAL (https://twitter.com/legalsylvain)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html).

from odoo import api, fields, models

from odoo.addons.barcodes_generator_abstract.models.barcode_rule\
    import _GENERATE_TYPE


class ProductTemplate(models.Model):
    _inherit = 'product.template'

    # Related to display product product information if is_product_variant
    barcode_rule_id = fields.Many2one(
        related='product_variant_ids.barcode_rule_id',
        string='Barcode Rule', readonly=False, comodel_name='barcode.rule')

    barcode_base = fields.Integer(
        related='product_variant_ids.barcode_base',
        readonly=False, string='Barcode Base')

    generate_type = fields.Selection(
        string='Generate Type', selection=_GENERATE_TYPE, readonly=True,
        related='product_variant_ids.barcode_rule_id.generate_type')

    # View Section
    @api.multi
    def generate_base(self):
        self.product_variant_ids.generate_base()

    @api.multi
    def generate_barcode(self):
        self.ensure_one()
        self.product_variant_ids.generate_barcode()

    @api.onchange('barcode_rule_id')
    def onchange_barcode_rule_id(self):
        self.generate_type = self.barcode_rule_id.generate_type

    @api.model_create_multi
    def create(self, vals_list):
        templates = super().create(vals_list)
        # This is needed to set given values to first variant after creation
        # (ref. product module feature in odoo core)
        for template, vals in zip(templates, vals_list):
            related_vals = {}
            if vals.get("barcode_rule_id"):
                related_vals["barcode_rule_id"] = vals["barcode_rule_id"]
            if vals.get("barcode_base"):
                related_vals["barcode_base"] = vals["barcode_base"]
            # An automatic barcode was generated, but we changed the barcode
            # rule. We need to revert the barcode.
            if (
                not vals.get("barcode")
                and vals.get("barcode_rule_id")
                and template.barcode
            ):
                related_vals["barcode"] = False
                related_vals["barcode_base"] = False
            if related_vals:
                template.write(related_vals)

        return templates
